<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../ui/AboutDialog.ui" line="14"/>
        <source>About Scan Tailor</source>
        <translation>關於 Scan Tailor</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="27"/>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="33"/>
        <source>Scan Tailor is an interactive post-processing tool for scanned pages. It performs operations such as page splitting, skew correction, adding/removing margins, and others. You give it raw scans, and you get pages ready to be printed or assembled into a PDF or DJVU file.  Scanning and optical character recognition is out of scope of this project.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="101"/>
        <source>Authors</source>
        <translation>作者群</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="125"/>
        <source>Lead Developer</source>
        <translation>主要開發成員</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="132"/>
        <source>Joseph Artsimovich</source>
        <translation>Joseph Artsimovich</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="157"/>
        <source>U235 - Picture auto-detection algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="164"/>
        <source>Robert B. - First generation dewarping algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="171"/>
        <source>Andrey Bergman - System load adjustment.</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../ui/AboutDialog.ui" line="178"/>
        <source>Petr Kovář - Command line interface.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="205"/>
        <source>Svetoslav Sashkov, Mandor - Bulgarian</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../ui/AboutDialog.ui" line="212"/>
        <source>Petr Kovář - Czech</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="219"/>
        <source>Stefan Birkner - German</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="226"/>
        <source>Angelo Gemmi - Italian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="233"/>
        <source>Masahiro Kitagawa - Japanese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="240"/>
        <source>Patrick Pascal - French</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../ui/AboutDialog.ui" line="247"/>
        <source>Daniel Koć - Polish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="254"/>
        <source>Joseph Artsimovich - Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../ui/AboutDialog.ui" line="261"/>
        <source>Marián Hvolka - Slovak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="268"/>
        <source>Flavio Benelli - Spanish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="275"/>
        <source>Davidson Wang - Traditional Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="282"/>
        <source>Yuri Chornoivan - Ukrainian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="309"/>
        <source>denver 22</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="190"/>
        <source>Translators</source>
        <translation>翻譯人員</translation>
    </message>
    <message>
        <source>Svetoslav Sashkov, Mandor - Bulgarian
               Stefan Birkner - German
               Angelo Gemmi - Italian
               Masahiro Kitagawa - Japanese
               Patrick Pascal - French
               Joseph Artsimovich - Russian
               Davidson Wang - Traditional Chinese</source>
        <translation type="obsolete">Svetoslav Sashkov, Mandor - Bulgarian
               Stefan Birkner - German
               Angelo Gemmi - Italian
               Masahiro Kitagawa - Japanese
               Patrick Pascal - French
               Joseph Artsimovich - Russian
               Davidson Wang - Traditional Chinese</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="142"/>
        <source>Contributors</source>
        <translation>貢獻者</translation>
    </message>
    <message>
        <source>U235 - Picture auto-detection algorithm.
Robert B. - Dewarping algorithm.
Andrey Bergman - System load adjustment.
</source>
        <translation type="obsolete">U235 - Picture 自動偵測演算法.
Robert B. - Dewarping 演算法.
Andrey Bergman - 系統負載調整.
</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="294"/>
        <source>Documentation</source>
        <translation>文件製作</translation>
    </message>
    <message>
        <source>denver 22
phaedrus
Taxman</source>
        <translation type="obsolete">denver 22
phaedrus
Taxman</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="350"/>
        <source>License</source>
        <translation>版權</translation>
    </message>
</context>
<context>
    <name>BatchProcessingLowerPanel</name>
    <message>
        <location filename="../ui/BatchProcessingLowerPanel.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/BatchProcessingLowerPanel.ui" line="36"/>
        <source>Beep when finished</source>
        <translation>完成時以&quot;嗶&quot;聲提示</translation>
    </message>
</context>
<context>
    <name>ColorPickupInteraction</name>
    <message>
        <location filename="../filters/output/ColorPickupInteraction.cpp" line="47"/>
        <source>Click on an area to pick up its color, or ESC to cancel.</source>
        <translation>以滑鼠左鍵在區域中挑選顏色，或按ESC鍵取消.</translation>
    </message>
</context>
<context>
    <name>DeskewApplyDialog</name>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="20"/>
        <source>Apply to</source>
        <translation type="unfinished">套用到</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="26"/>
        <source>This page only (already applied)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="36"/>
        <source>All pages</source>
        <translation type="unfinished">所有頁面</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="43"/>
        <source>This page and the following ones</source>
        <translation type="unfinished">本頁及以下的頁面</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="59"/>
        <source>Selected pages</source>
        <translation type="unfinished">選擇的頁面</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="92"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation type="unfinished">使用 Ctrl或Shift+滑鼠左鍵來選擇多個頁面.</translation>
    </message>
</context>
<context>
    <name>DeskewOptionsWidget</name>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="20"/>
        <source>Deskew</source>
        <translation>糾偏</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="41"/>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="57"/>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="140"/>
        <source>Apply To ...</source>
        <translation type="unfinished">套用到...</translation>
    </message>
</context>
<context>
    <name>DragHandler</name>
    <message>
        <location filename="../interaction/DragHandler.cpp" line="46"/>
        <source>Unrestricted dragging is possible by holding down the Shift key.</source>
        <translation>長按 Shift 鍵可以自由移動畫面.</translation>
    </message>
</context>
<context>
    <name>FixDpiDialog</name>
    <message>
        <source>Need Fixing</source>
        <translation type="obsolete">需要修正</translation>
    </message>
    <message>
        <source>All Pages</source>
        <translation type="obsolete">所有頁面</translation>
    </message>
    <message>
        <source>DPI is too large and most likely wrong.</source>
        <translation type="obsolete">最有可能的狀況是DPI太大了.</translation>
    </message>
    <message>
        <source>DPI is too small. Even if it&apos;s correct, you are not going to get acceptable results with it.</source>
        <translation type="obsolete">DPI太小. 即使數值是正確的,你也不見得會接受這樣的結果.</translation>
    </message>
    <message>
        <source>DPI is too small for this pixel size. Such combination would probably lead to out of memory errors.</source>
        <translation type="obsolete">對於這樣的尺寸來說DPI過小. 這樣的組合可能會導致記憶體溢位錯誤.</translation>
    </message>
    <message>
        <source>%1 (page %2)</source>
        <translation type="obsolete">%1 (第 %2 頁)</translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="13"/>
        <source>Fix DPI</source>
        <translation>修正DPI</translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="23"/>
        <source>Tab 1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="33"/>
        <source>Tab 2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="46"/>
        <source>DPI</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="69"/>
        <source>Custom</source>
        <translation>自訂</translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="90"/>
        <source>x</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="113"/>
        <source>Apply</source>
        <translation>套用</translation>
    </message>
</context>
<context>
    <name>FixDpiSinglePageDialog</name>
    <message>
        <source>Fix DPI</source>
        <translation type="obsolete">修正DPI</translation>
    </message>
    <message>
        <source>DPI for %1</source>
        <translation type="obsolete">%1的DPI</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation type="obsolete">自訂</translation>
    </message>
    <message>
        <source>%1 (page %2)</source>
        <translation type="obsolete">%1 (第 %2 頁)</translation>
    </message>
    <message>
        <source>DPI is too large and most likely wrong.</source>
        <translation type="obsolete">最有可能的狀況是DPI太大了.</translation>
    </message>
    <message>
        <source>DPI is too small. Even if it&apos;s correct, you are not going to get acceptable results with it.</source>
        <translation type="obsolete">DPI太小. 即使數值是正確的,你也不見得會接受這樣的結果.</translation>
    </message>
    <message>
        <source>DPI is too small for this pixel size. Such combination would probably lead to out of memory errors.</source>
        <translation type="obsolete">對於這樣的尺寸來說DPI過小. 這樣的組合可能會導致記憶體溢位錯誤.</translation>
    </message>
</context>
<context>
    <name>ImageViewBase</name>
    <message>
        <source>Use the mouse wheel or +/- to zoom.  When zoomed, dragging is possible.</source>
        <translation type="obsolete">使用滑鼠滾輪或+/-鍵來縮放. 縮放後可對圖片進行拖曳移動.</translation>
    </message>
</context>
<context>
    <name>InteractiveXSpline</name>
    <message>
        <location filename="../interaction/InteractiveXSpline.cpp" line="47"/>
        <source>Click to create a new control point.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../interaction/InteractiveXSpline.cpp" line="73"/>
        <source>This point can be dragged.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../interaction/InteractiveXSpline.cpp" line="75"/>
        <source>Drag this point or delete it by pressing Del or D.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoadFileTask</name>
    <message>
        <source>The following file could not be loaded:
%1</source>
        <translation type="obsolete">無法載入下列檔案:
%1</translation>
    </message>
</context>
<context>
    <name>LoadFilesStatusDialog</name>
    <message>
        <location filename="../ui/LoadFilesStatusDialog.ui" line="14"/>
        <source>Some files failed to load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/LoadFilesStatusDialog.ui" line="27"/>
        <source>Loaded successfully: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/LoadFilesStatusDialog.ui" line="87"/>
        <source>Failed to load: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/MainWindow.ui" line="232"/>
        <source>Save Project</source>
        <translation>儲存專案</translation>
    </message>
    <message>
        <source>Save this project?</source>
        <translation type="obsolete">是否要儲存此專案?</translation>
    </message>
    <message>
        <source>Insert before ...</source>
        <translation type="obsolete">插入在此之前...</translation>
    </message>
    <message>
        <source>Insert after ...</source>
        <translation type="obsolete">插入在此之後...</translation>
    </message>
    <message>
        <source>Remove from project ...</source>
        <translation type="obsolete">從專案中移除...</translation>
    </message>
    <message>
        <source>Insert here ...</source>
        <translation type="obsolete">在此插入...</translation>
    </message>
    <message>
        <source>Scan Tailor Projects</source>
        <translation type="obsolete">Scan Tailor 專案</translation>
    </message>
    <message>
        <source>Open Project</source>
        <translation type="obsolete">開啟專案</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="obsolete">錯誤</translation>
    </message>
    <message>
        <source>Unable to open the project file.</source>
        <translation type="obsolete">無法開啟專案檔.</translation>
    </message>
    <message>
        <source>The project file is broken.</source>
        <translation type="obsolete">專案檔已毀損.</translation>
    </message>
    <message>
        <source>Output is not yet possible, as the final size of pages is not yet known.
To determine it, run batch processing at &quot;Select Content&quot; or &quot;Margins&quot;.</source>
        <translation type="obsolete">目前無法輸出,因為沒有指定輸出的頁面範圍.
請使用批次處理中的&quot;內容選擇&quot;或&quot;邊界&quot;項目來偵測與指定範圍.</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation type="obsolete">未命名</translation>
    </message>
    <message>
        <source>Error saving the project file!</source>
        <translation type="obsolete">儲存時發生錯誤!</translation>
    </message>
    <message>
        <source>File to insert</source>
        <translation type="obsolete">插入檔案</translation>
    </message>
    <message>
        <source>Images not in project (%1)</source>
        <translation type="obsolete">專案外的圖片 (%1)</translation>
    </message>
    <message>
        <source>Error opening the image file.</source>
        <translation type="obsolete">開啟影像時發生錯誤.</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="obsolete">移除</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="20"/>
        <source>MainWindow</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="130"/>
        <source>Keep current page in view.</source>
        <translation>保持縮圖與處理畫面同步.</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="156"/>
        <source>Use Home, End, PgUp (or Q), PgDown (or W) to navigate between pages.</source>
        <translation>使用 Home鍵, PgUp(或Q)鍵, PgDown(或W)鍵來尋覽頁面.</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="185"/>
        <source>Tools</source>
        <translation>工具</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="196"/>
        <source>File</source>
        <translation>檔案</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="210"/>
        <source>Help</source>
        <translation>說明</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation type="obsolete">除錯</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="227"/>
        <source>Debug Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="235"/>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="240"/>
        <source>Save Project As ...</source>
        <translation>另存專案檔...</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="245"/>
        <location filename="../ui/MainWindow.ui" line="294"/>
        <source>Next Page</source>
        <translation>下一頁</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="248"/>
        <source>PgDown</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="256"/>
        <location filename="../ui/MainWindow.ui" line="283"/>
        <source>Previous Page</source>
        <translation>上一頁</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="259"/>
        <source>PgUp</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="267"/>
        <source>New Project ...</source>
        <translation>建立新專案...</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="270"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="275"/>
        <source>Open Project ...</source>
        <translation>開啟專案...</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="278"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="286"/>
        <source>Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="297"/>
        <source>W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="305"/>
        <source>Close Project</source>
        <translation>關閉專案</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="308"/>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="313"/>
        <source>Quit</source>
        <translation>結束程式</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="316"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="326"/>
        <source>First Page</source>
        <translation>第一頁</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="329"/>
        <source>Home</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="334"/>
        <source>Last Page</source>
        <translation>最後頁</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="337"/>
        <source>End</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="342"/>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="347"/>
        <source>Fix DPI ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="352"/>
        <source>Relinking ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop batch processing</source>
        <translation type="obsolete">停止批次處理</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="321"/>
        <source>Settings ...</source>
        <translation>設定...</translation>
    </message>
</context>
<context>
    <name>NewOpenProjectPanel</name>
    <message>
        <location filename="../ui/NewOpenProjectPanel.ui" line="19"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/NewOpenProjectPanel.ui" line="52"/>
        <source>New Project ...</source>
        <translation>建立新專案...</translation>
    </message>
    <message>
        <location filename="../ui/NewOpenProjectPanel.ui" line="78"/>
        <source>Open Project ...</source>
        <translation>開啟專案...</translation>
    </message>
    <message>
        <location filename="../ui/NewOpenProjectPanel.ui" line="103"/>
        <source>Recent Projects</source>
        <translation>最近使用的專案</translation>
    </message>
</context>
<context>
    <name>OrientationApplyDialog</name>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="17"/>
        <source>Fix Orientation</source>
        <translation>修正方向</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="23"/>
        <source>Apply to</source>
        <translation>套用到</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="29"/>
        <source>This page only (already applied)</source>
        <translation>只有這一頁. (已經套用了)</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="39"/>
        <source>All pages</source>
        <translation>所有頁面</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="46"/>
        <source>This page and the following ones</source>
        <translation>本頁及以下的頁面</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="71"/>
        <source>Every other page</source>
        <extracomment>All odd or even pages, depending on the current page being odd or even.</extracomment>
        <translatorcomment>所有奇數與偶數頁面, 會根據目前的頁面是奇數或偶數.</translatorcomment>
        <translation>所有其他頁面</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="101"/>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="206"/>
        <source>The current page will be included.</source>
        <translation>將會包含目前的頁面.</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="125"/>
        <source>Selected pages</source>
        <translation>選擇的頁面</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="155"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>使用 Ctrl或Shift+滑鼠左鍵來選擇多個頁面.</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="176"/>
        <source>Every other selected page</source>
        <translation>所有其他選擇的頁面</translation>
    </message>
</context>
<context>
    <name>OrientationOptionsWidget</name>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="13"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="19"/>
        <source>Rotate</source>
        <translation>旋轉</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="40"/>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="56"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="142"/>
        <source>Reset</source>
        <translation>重設</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="167"/>
        <source>Scope</source>
        <translation>範圍</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="188"/>
        <source>Apply to ...</source>
        <translation>套用到...</translation>
    </message>
</context>
<context>
    <name>OutOfMemoryDialog</name>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="14"/>
        <source>Out of memory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="37"/>
        <source>Out of Memory Situation in Scan Tailor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="70"/>
        <source>Possible reasons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="103"/>
        <source>Did you have to fix the DPI of your source images? Are you sure the values you entered were correct?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="123"/>
        <source>Sometimes your source images may have wrong DPI embedded into them. Scan Tailor tries to detect those, but it&apos;s not always easy to tell. You may need to check &quot;Fix DPI even if they look normal&quot; when creating a project and look into &quot;All pages&quot; tab in the &quot;Fix DPI&quot; dialog, which is also accessible from the Tools menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="143"/>
        <source>Is your output DPI set too high? Usually you don&apos;t need it higher than 600.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="174"/>
        <source>What can help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="204"/>
        <source>Fix your DPIs. Learn how to &lt;a href=&quot;http://vimeo.com/12524529&quot;&gt;estimate unknown DPIs&lt;/a&gt;.</source>
        <extracomment>Feel free to change the URL to a localized video / text tutorial.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="224"/>
        <source>If your hardware and operating system are 64-bit capable, consider switching to a 64-bit version of Scan Tailor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="244"/>
        <source>When working with grayscale images, make sure they are really grayscale. If they are actually color images that just happen to look grayscale, convert them to grayscale using some kind of batch image converter. This will both save memory and increase performance.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="264"/>
        <source>As a last resort, you can save some memory by making sure thumbnails are pre-created rather than created on demand. This can be done by slowly scrolling the thumbnail list all the way from top to bottom before starting any real work.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="295"/>
        <source>What won&apos;t help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="325"/>
        <source>Surprisingly, upgrading your RAM won&apos;t help here. The lack of RAM is compensated by the swap mechanism, which makes things slow, but keeps programs running. An out of memory situation means we ran out of memory address space, which has nothing to do with the amount of RAM you have. The only way to increase the memory address space is to go 64-bit hardware, 64-bit operating system and 64-bit Scan Tailor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="361"/>
        <source>Save Project</source>
        <translation type="unfinished">儲存專案</translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="384"/>
        <source>Save Project As ...</source>
        <translation type="unfinished">另存專案檔...</translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="404"/>
        <source>Don&apos;t Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="421"/>
        <source>Project Saved Successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="453"/>
        <source>Please note that while Scan Tailor tries to catch out-of-memory situations and give you the opportunity to save your project, it&apos;s not always possible. This time it succeeded, but the next time it might just crash.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OutputApplyColorsDialog</name>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="17"/>
        <source>Apply Mode</source>
        <translation>套用模式</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="23"/>
        <source>Apply to</source>
        <translation>套用到</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="29"/>
        <source>This page only (already applied)</source>
        <translation>只有目前頁面 (已經套用了)</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="39"/>
        <source>All pages</source>
        <translation>所有頁面</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="46"/>
        <source>This page and the following ones</source>
        <translation>本頁及以下的頁面</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="62"/>
        <source>Selected pages</source>
        <translation>選擇的頁面</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="95"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>使用 Ctrl或Shift+滑鼠左鍵來選擇多個頁面.</translation>
    </message>
</context>
<context>
    <name>OutputChangeDewarpingDialog</name>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="17"/>
        <source>Apply Dewarping Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="23"/>
        <source>Mode</source>
        <translation type="unfinished">模式</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="29"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="42"/>
        <source>Auto (experimental)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="49"/>
        <source>Manual</source>
        <translation type="unfinished">手動</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="59"/>
        <source>Scope</source>
        <translation type="unfinished">範圍</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="65"/>
        <source>This page only</source>
        <translation type="unfinished">只有這一頁</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="75"/>
        <source>All pages</source>
        <translation type="unfinished">所有頁面</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="82"/>
        <source>This page and the following ones</source>
        <translation type="unfinished">本頁及以下的頁面</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="98"/>
        <source>Selected pages</source>
        <translation type="unfinished">選擇的頁面</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="131"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation type="unfinished">使用 Ctrl或Shift+滑鼠左鍵來選擇多個頁面.</translation>
    </message>
</context>
<context>
    <name>OutputChangeDpiDialog</name>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="17"/>
        <source>Apply Output Resolution</source>
        <translation>套用輸出解析度</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="23"/>
        <source>DPI</source>
        <translation>DPI</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="68"/>
        <source>Scope</source>
        <translation>範圍</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="74"/>
        <source>This page only</source>
        <translation>只有這一頁</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="91"/>
        <source>This page and the following ones</source>
        <translation>本頁及以下的頁面</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="107"/>
        <source>Selected pages</source>
        <translation>選擇的頁面</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="140"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>使用 Ctrl或Shift+滑鼠左鍵來選擇多個頁面.</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="84"/>
        <source>All pages</source>
        <translation>所有頁面</translation>
    </message>
</context>
<context>
    <name>OutputOptionsWidget</name>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="20"/>
        <source>Output Resolution (DPI)</source>
        <translation>輸出解析度 (DPI)</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="78"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="419"/>
        <source>Change ...</source>
        <translation>變更...</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="103"/>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="169"/>
        <source>White margins</source>
        <translation>空白邊界</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="176"/>
        <source>Equalize illumination</source>
        <translation>等化亮度</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="361"/>
        <source>Dewarping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="444"/>
        <source>Depth perception</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="533"/>
        <source>No despeckling</source>
        <translation>不進行雜點清除</translation>
    </message>
    <message>
        <source>Dewarp</source>
        <translation type="obsolete">消除彎曲變形</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="336"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="484"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="666"/>
        <source>Apply To ...</source>
        <translation>套用到...</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="509"/>
        <source>Despeckling</source>
        <translation>雜點清除</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="558"/>
        <source>Cautious despeckling</source>
        <translation>輕微的雜點清除</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="561"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="587"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="613"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="584"/>
        <source>Normal despeckling</source>
        <translation>普通的雜點清除</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="610"/>
        <source>Aggressive despeckling</source>
        <translation>強力的雜點清除</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="274"/>
        <source>Thinner</source>
        <translation>較細的</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="306"/>
        <source>Thicker</source>
        <translation>較粗的</translation>
    </message>
</context>
<context>
    <name>PageLayoutApplyDialog</name>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="20"/>
        <source>Apply to</source>
        <translation>套用到</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="26"/>
        <source>This page only (already applied)</source>
        <translation>只有這一頁. (已經套用了)</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="36"/>
        <source>All pages</source>
        <translation>所有頁面</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="43"/>
        <source>This page and the following ones</source>
        <translation>本頁及以下的頁面</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="59"/>
        <source>Every other page</source>
        <extracomment>All odd or even pages, depending on the current page being odd or even.</extracomment>
        <translation type="unfinished">所有其他頁面</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="89"/>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="194"/>
        <source>The current page will be included.</source>
        <translation type="unfinished">將會包含目前的頁面.</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="110"/>
        <source>Selected pages</source>
        <translation>選擇的頁面</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="143"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>使用 Ctrl或Shift+滑鼠左鍵來選擇多個頁面.</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="164"/>
        <source>Every other selected page</source>
        <translation type="unfinished">所有其他選擇的頁面</translation>
    </message>
</context>
<context>
    <name>PageLayoutOptionsWidget</name>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="20"/>
        <source>Margins</source>
        <translation>邊距</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="42"/>
        <source>Millimeters (mm)</source>
        <translation>公厘 (mm)</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="47"/>
        <source>Inches (in)</source>
        <translation>英吋 (in)</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="87"/>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="100"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="161"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="338"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="361"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="384"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="407"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="430"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="456"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="479"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="502"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="525"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="121"/>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="138"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="185"/>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="244"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="580"/>
        <source>Apply To ...</source>
        <translation>套用到...</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="269"/>
        <source>Alignment</source>
        <translation>對齊</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="293"/>
        <source>Match size with other pages</source>
        <translation>與其他頁面大小相同</translation>
    </message>
</context>
<context>
    <name>PageSplitModeDialog</name>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="17"/>
        <source>Split Pages</source>
        <translation>切割頁面</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="63"/>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="69"/>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="79"/>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="89"/>
        <source>Scope</source>
        <translation>範圍</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="95"/>
        <source>This page only</source>
        <translation>只有這一頁</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="112"/>
        <source>This page and the following ones</source>
        <translation>本頁及以下的頁面</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="128"/>
        <source>Selected pages</source>
        <translation>選擇的頁面</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="161"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>使用 Ctrl或Shift+滑鼠左鍵來選擇多個頁面.</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="105"/>
        <source>All pages</source>
        <translation>所有頁面</translation>
    </message>
</context>
<context>
    <name>PageSplitOptionsWidget</name>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="20"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="26"/>
        <source>Page Layout</source>
        <translation>頁面佈局</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="134"/>
        <source>?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="159"/>
        <source>Change ...</source>
        <translation>變更...</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="184"/>
        <source>Split Line</source>
        <translation>分割線</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="214"/>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="230"/>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
</context>
<context>
    <name>PictureZonePropDialog</name>
    <message>
        <location filename="../filters/output/ui/PictureZonePropDialog.ui" line="14"/>
        <source>Zone Properties</source>
        <translation>區塊屬性</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/PictureZonePropDialog.ui" line="20"/>
        <source>Subtract from all layers</source>
        <translation>從所有的圖層中刪減</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/PictureZonePropDialog.ui" line="27"/>
        <source>Add to auto layer</source>
        <translation>加入到自動圖層</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/PictureZonePropDialog.ui" line="34"/>
        <source>Subtract from auto layer</source>
        <translation>從所有的自動圖層中刪減</translation>
    </message>
</context>
<context>
    <name>ProjectFilesDialog</name>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="20"/>
        <source>Input Directory</source>
        <translation>輸入目錄</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="43"/>
        <source>Output Directory</source>
        <translation>輸出目錄</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="obsolete">錯誤</translation>
    </message>
    <message>
        <source>No files in project!</source>
        <translation type="obsolete">專案中無任何檔案!</translation>
    </message>
    <message>
        <source>Input directory is not set or doesn&apos;t exist.</source>
        <translation type="obsolete">沒有設定輸入目錄或指定的目錄不存在.</translation>
    </message>
    <message>
        <source>Input and output directories can&apos;t be the same.</source>
        <translation type="obsolete">輸入與輸出目錄不得相同.</translation>
    </message>
    <message>
        <source>Create Directory?</source>
        <translation type="obsolete">建立目錄?</translation>
    </message>
    <message>
        <source>Output directory doesn&apos;t exist.  Create it?</source>
        <translation type="obsolete">輸出目錄不存在. 是否要建立?</translation>
    </message>
    <message>
        <source>Unable to create output directory.</source>
        <translation type="obsolete">無法建立輸出目錄.</translation>
    </message>
    <message>
        <source>Output directory is not set or doesn&apos;t exist.</source>
        <translation type="obsolete">沒有設定輸出目錄或指定的目錄不存在.</translation>
    </message>
    <message>
        <source>Some of the files failed to load.
Either we don&apos;t support their format, or they are broken.
You should remove them from the project.</source>
        <translation type="obsolete">某些檔案載入失敗.
可能是不被支援的檔案類型或是檔案損壞.
您必須從專案中移除那些檔案.</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="14"/>
        <source>Project Files</source>
        <translation>專案檔案</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="33"/>
        <location filename="../ui/ProjectFilesDialog.ui" line="52"/>
        <source>Browse</source>
        <translation>瀏覽</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="64"/>
        <source>Files Not In Project</source>
        <translation>專案外的檔案</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="77"/>
        <location filename="../ui/ProjectFilesDialog.ui" line="159"/>
        <source>Select All</source>
        <translation>全選</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="102"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Add selected files to project.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;加入選擇的項目到專案中.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="108"/>
        <source>&gt;&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="115"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Remove selected files from project.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;從專案中移除選擇的檔案.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="121"/>
        <source>&lt;&lt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="143"/>
        <source>Files In Project</source>
        <translation>專案中的檔案</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="171"/>
        <source>Right to left layout (for Hebrew and Arabic)</source>
        <translation>從右至左的佈局 (希伯來語和阿拉伯語)</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="178"/>
        <source>Fix DPIs, even if they look OK</source>
        <translation>總是修正DPI</translation>
    </message>
</context>
<context>
    <name>ProjectOpeningContext</name>
    <message>
        <source>Error</source>
        <translation type="obsolete">錯誤</translation>
    </message>
    <message>
        <source>Unable to interpret the project file.</source>
        <translation type="obsolete">無法解讀專案檔.</translation>
    </message>
</context>
<context>
    <name>RelinkingDialog</name>
    <message>
        <location filename="../ui/RelinkingDialog.ui" line="14"/>
        <source>Relinking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/RelinkingDialog.ui" line="97"/>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/RelinkingDialog.ui" line="100"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RemovePagesDialog</name>
    <message>
        <location filename="../ui/RemovePagesDialog.ui" line="14"/>
        <source>Remove Pages</source>
        <translation>移除頁面</translation>
    </message>
    <message>
        <location filename="../ui/RemovePagesDialog.ui" line="57"/>
        <source>Remove %1 page(s) from project?</source>
        <translation>是否要從專案中移除這 %1 頁?</translation>
    </message>
    <message>
        <location filename="../ui/RemovePagesDialog.ui" line="72"/>
        <source>Corresponding output files will be deleted, while input files will remain.</source>
        <translation>輸出目錄中的檔案將被刪除, 原始輸入檔案會保留.</translation>
    </message>
</context>
<context>
    <name>SelectContentApplyDialog</name>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="17"/>
        <source>Select Content</source>
        <translation type="unfinished">選擇內容</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="23"/>
        <source>Apply to</source>
        <translation type="unfinished">套用到</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="29"/>
        <source>This page only (already applied)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="39"/>
        <source>All pages</source>
        <translation type="unfinished">所有頁面</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="46"/>
        <source>This page and the following ones</source>
        <translation type="unfinished">本頁及以下的頁面</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="71"/>
        <source>Every other page</source>
        <extracomment>All odd or even pages, depending on the current page being odd or even.</extracomment>
        <translation type="unfinished">所有其他頁面</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="101"/>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="206"/>
        <source>The current page will be included.</source>
        <translation type="unfinished">將會包含目前的頁面.</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="125"/>
        <source>Selected pages</source>
        <translation type="unfinished">選擇的頁面</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="155"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation type="unfinished">使用 Ctrl或Shift+滑鼠左鍵來選擇多個頁面.</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="176"/>
        <source>Every other selected page</source>
        <translation type="unfinished">所有其他選擇的頁面</translation>
    </message>
</context>
<context>
    <name>SelectContentOptionsWidget</name>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="13"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="19"/>
        <source>Content Box</source>
        <translation>內容區塊</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="38"/>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="54"/>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="83"/>
        <source>Scope</source>
        <translation type="unfinished">範圍</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="104"/>
        <source>Apply to ...</source>
        <translation type="unfinished">套用到...</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Compiled without OpenGL support.</source>
        <translation type="obsolete">沒有支援OpenGL的編譯.</translation>
    </message>
    <message>
        <source>Your hardware / driver don&apos;t provide the necessary features.</source>
        <translation type="obsolete">您的硬體/驅動程式沒有支援所需要的功能.</translation>
    </message>
    <message>
        <location filename="../ui/SettingsDialog.ui" line="14"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../ui/SettingsDialog.ui" line="20"/>
        <source>Use 3D acceleration for user interface</source>
        <translation>對使用者介面使用3D加速</translation>
    </message>
</context>
<context>
    <name>StageListView</name>
    <message>
        <source>Launch batch processing</source>
        <translation type="obsolete">開始批次處理程序</translation>
    </message>
</context>
<context>
    <name>SystemLoadWidget</name>
    <message>
        <location filename="../ui/SystemLoadWidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/SystemLoadWidget.ui" line="23"/>
        <source>System load</source>
        <translation>系統負載</translation>
    </message>
    <message>
        <location filename="../ui/SystemLoadWidget.ui" line="46"/>
        <location filename="../ui/SystemLoadWidget.ui" line="73"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <source>Minimal</source>
        <translation type="obsolete">最小</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="obsolete">普通</translation>
    </message>
</context>
<context>
    <name>ThumbnailSequence</name>
    <message>
        <source>%1 (page %2)</source>
        <translation type="obsolete">%1 (第 %2 頁)</translation>
    </message>
</context>
<context>
    <name>ZoneContextMenuInteraction</name>
    <message>
        <location filename="../zones/ZoneContextMenuInteraction.cpp" line="275"/>
        <source>Properties</source>
        <translation>屬性</translation>
    </message>
    <message>
        <location filename="../zones/ZoneContextMenuInteraction.cpp" line="265"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="../zones/ZoneContextMenuInteraction.cpp" line="249"/>
        <source>Delete confirmation</source>
        <translation>確認刪除</translation>
    </message>
    <message>
        <location filename="../zones/ZoneContextMenuInteraction.cpp" line="249"/>
        <source>Really delete this zone?</source>
        <translation>是否真的要刪除這個區域?</translation>
    </message>
</context>
<context>
    <name>ZoneCreationInteraction</name>
    <message>
        <location filename="../zones/ZoneCreationInteraction.cpp" line="206"/>
        <source>Click to finish this zone.  ESC to cancel.</source>
        <translation>按下滑鼠左鍵來標定區域. 按ESC鍵取消.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneCreationInteraction.cpp" line="208"/>
        <source>Connect first and last points to finish this zone.  ESC to cancel.</source>
        <translation>將起點與終點相連已完成區域的劃定. 按下ESC鍵取消.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneCreationInteraction.cpp" line="211"/>
        <source>Zones need to have at least 3 points.  ESC to cancel.</source>
        <translation>至少需要3個點來標定區域. 按ESC鍵取消.</translation>
    </message>
</context>
<context>
    <name>ZoneDefaultInteraction</name>
    <message>
        <location filename="../zones/ZoneDefaultInteraction.cpp" line="45"/>
        <source>Drag the vertex.</source>
        <translation>拖曳頂點.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneDefaultInteraction.cpp" line="46"/>
        <source>Click to create a new vertex here.</source>
        <translation>在此按下滑鼠左鍵來建立頂點.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneDefaultInteraction.cpp" line="47"/>
        <source>Right click to edit zone properties.</source>
        <translation>按下滑鼠右鍵來編輯區域屬性.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneDefaultInteraction.cpp" line="49"/>
        <source>Click to start creating a new picture zone.</source>
        <translation>按下滑鼠左鍵來建立新的圖片範圍.</translation>
    </message>
</context>
<context>
    <name>ZoneVertexDragInteraction</name>
    <message>
        <location filename="../zones/ZoneVertexDragInteraction.cpp" line="160"/>
        <source>Merge these two vertices.</source>
        <translation>合併這兩個頂點.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneVertexDragInteraction.cpp" line="162"/>
        <source>Move the vertex to one of its neighbors to merge them.</source>
        <translation>與最新進的頂點進行合併.</translation>
    </message>
</context>
<context>
    <name>deskew::Filter</name>
    <message>
        <location filename="../filters/deskew/Filter.cpp" line="57"/>
        <source>Deskew</source>
        <translation>糾偏</translation>
    </message>
</context>
<context>
    <name>deskew::ImageView</name>
    <message>
        <location filename="../filters/deskew/ImageView.cpp" line="62"/>
        <source>Use Ctrl+Wheel to rotate or Ctrl+Shift+Wheel for finer rotation.</source>
        <translation>使用 Ctrl+滑鼠滾輪來旋轉或Shift+滑鼠滾輪來微調旋轉.</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ImageView.cpp" line="65"/>
        <source>Drag this handle to rotate the image.</source>
        <translation>拖曳此點來旋轉頁面.</translation>
    </message>
</context>
<context>
    <name>deskew::OptionsWidget</name>
    <message>
        <location filename="../filters/deskew/OptionsWidget.cpp" line="69"/>
        <source>Apply Deskew</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>fix_orientation::ApplyDialog</name>
    <message>
        <location filename="../filters/fix_orientation/ApplyDialog.cpp" line="53"/>
        <source>Can&apos;t do: more than one group is selected.</source>
        <translation type="unfinished">無法進行動作: 超過一個以上的群組被選取.</translation>
    </message>
</context>
<context>
    <name>fix_orientation::Filter</name>
    <message>
        <location filename="../filters/fix_orientation/Filter.cpp" line="64"/>
        <source>Fix Orientation</source>
        <translation>修正方向</translation>
    </message>
</context>
<context>
    <name>output::ChangeDpiDialog</name>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="72"/>
        <source>Custom</source>
        <translation>自訂</translation>
    </message>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="131"/>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="140"/>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="148"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="132"/>
        <source>DPI is not set.</source>
        <translation>尚未設定DPI.</translation>
    </message>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="141"/>
        <source>DPI is too low!</source>
        <translation>DPI值太低!</translation>
    </message>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="149"/>
        <source>DPI is too high!</source>
        <translation>DPI值太高!</translation>
    </message>
</context>
<context>
    <name>output::FillZoneEditor</name>
    <message>
        <location filename="../filters/output/FillZoneEditor.cpp" line="226"/>
        <source>Pick color</source>
        <translation>挑選顏色</translation>
    </message>
</context>
<context>
    <name>output::Filter</name>
    <message>
        <location filename="../filters/output/Filter.cpp" line="63"/>
        <source>Output</source>
        <translation>輸出</translation>
    </message>
</context>
<context>
    <name>output::OptionsWidget</name>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="63"/>
        <source>Black and White</source>
        <translation>單色(黑白)</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="64"/>
        <source>Color / Grayscale</source>
        <translation>彩色 / 灰階</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="65"/>
        <source>Mixed</source>
        <translation>混合</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="407"/>
        <source>Apply Despeckling Level</source>
        <translation>套用雜點清除</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="487"/>
        <source>Apply Depth Perception</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="660"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="663"/>
        <source>Auto</source>
        <translation type="unfinished">自動</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="666"/>
        <source>Manual</source>
        <translation type="unfinished">手動</translation>
    </message>
</context>
<context>
    <name>output::Task::UiUpdater</name>
    <message>
        <location filename="../filters/output/Task.cpp" line="506"/>
        <source>Picture zones are only available in Mixed mode.</source>
        <translation>圖形範圍只能在混合模式中.</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="558"/>
        <source>Despeckling can&apos;t be done in Color / Grayscale mode.</source>
        <translation>雜點清除無法在 彩色/灰階 模式中使用.</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="575"/>
        <source>Output</source>
        <translation>輸出</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="576"/>
        <source>Picture Zones</source>
        <translation>圖片區域</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="577"/>
        <source>Fill Zones</source>
        <translation>填滿區域</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="578"/>
        <source>Dewarping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="579"/>
        <source>Despeckling</source>
        <translation>雜點清除</translation>
    </message>
</context>
<context>
    <name>page_layout::ApplyDialog</name>
    <message>
        <location filename="../filters/page_layout/ApplyDialog.cpp" line="51"/>
        <source>Can&apos;t do: more than one group is selected.</source>
        <translation type="unfinished">無法進行動作: 超過一個以上的群組被選取.</translation>
    </message>
</context>
<context>
    <name>page_layout::Filter</name>
    <message>
        <location filename="../filters/page_layout/Filter.cpp" line="67"/>
        <source>Natural order</source>
        <translation>自然排序</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/Filter.cpp" line="68"/>
        <source>Order by increasing width</source>
        <translation>寬度遞增排序</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/Filter.cpp" line="69"/>
        <source>Order by increasing height</source>
        <translation>高度遞增排序</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/Filter.cpp" line="79"/>
        <source>Margins</source>
        <translation>邊距</translation>
    </message>
</context>
<context>
    <name>page_layout::ImageView</name>
    <message>
        <location filename="../filters/page_layout/ImageView.cpp" line="76"/>
        <source>Resize margins by dragging any of the solid lines.</source>
        <translation>拖曳線段可以用來調整邊距大小.</translation>
    </message>
</context>
<context>
    <name>page_layout::OptionsWidget</name>
    <message>
        <location filename="../filters/page_layout/OptionsWidget.cpp" line="310"/>
        <source>Apply Margins</source>
        <translation>套用邊距設定</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/OptionsWidget.cpp" line="325"/>
        <source>Apply Alignment</source>
        <translation>套用對齊設定</translation>
    </message>
</context>
<context>
    <name>page_split::Filter</name>
    <message>
        <location filename="../filters/page_split/Filter.cpp" line="65"/>
        <source>Natural order</source>
        <translation type="unfinished">自然排序</translation>
    </message>
    <message>
        <location filename="../filters/page_split/Filter.cpp" line="66"/>
        <source>Order by split type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/page_split/Filter.cpp" line="76"/>
        <source>Split Pages</source>
        <translation>分割頁面</translation>
    </message>
</context>
<context>
    <name>page_split::ImageView</name>
    <message>
        <location filename="../filters/page_split/ImageView.cpp" line="85"/>
        <source>Drag the line or the handles.</source>
        <translation>拖曳線段或控制點.</translation>
    </message>
</context>
<context>
    <name>page_split::OptionsWidget</name>
    <message>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="116"/>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="208"/>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="301"/>
        <source>Set manually</source>
        <translation>設為手動</translation>
    </message>
    <message>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="165"/>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="298"/>
        <source>Auto detected</source>
        <translation>自動選擇</translation>
    </message>
</context>
<context>
    <name>page_split::UnremoveButton</name>
    <message>
        <location filename="../filters/page_split/UnremoveButton.cpp" line="38"/>
        <source>Restore removed page.</source>
        <translation>復原被移除的頁面.</translation>
    </message>
</context>
<context>
    <name>select_content::ApplyDialog</name>
    <message>
        <location filename="../filters/select_content/ApplyDialog.cpp" line="53"/>
        <source>Can&apos;t do: more than one group is selected.</source>
        <translation type="unfinished">無法進行動作: 超過一個以上的群組被選取.</translation>
    </message>
</context>
<context>
    <name>select_content::Filter</name>
    <message>
        <location filename="../filters/select_content/Filter.cpp" line="59"/>
        <source>Natural order</source>
        <translation>自然排序</translation>
    </message>
    <message>
        <location filename="../filters/select_content/Filter.cpp" line="60"/>
        <source>Order by increasing width</source>
        <translation>寬度遞增排序</translation>
    </message>
    <message>
        <location filename="../filters/select_content/Filter.cpp" line="61"/>
        <source>Order by increasing height</source>
        <translation>高度遞增排序</translation>
    </message>
    <message>
        <location filename="../filters/select_content/Filter.cpp" line="71"/>
        <source>Select Content</source>
        <translation>選擇內容</translation>
    </message>
</context>
<context>
    <name>select_content::ImageView</name>
    <message>
        <location filename="../filters/select_content/ImageView.cpp" line="58"/>
        <source>Use the context menu to enable / disable the content box.</source>
        <translation>使用內容選單來 啟用/停用 內容區塊.</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ImageView.cpp" line="61"/>
        <source>Drag lines or corners to resize the content box.</source>
        <translation>拖曳線段或角落來調整內容區塊大小.</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ImageView.cpp" line="107"/>
        <source>Create Content Box</source>
        <translation>建立內容區塊</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ImageView.cpp" line="108"/>
        <source>Remove Content Box</source>
        <translation>移除內容區塊</translation>
    </message>
</context>
</TS>
